using Godot;
using System;

public partial class player : CharacterBody2D
{
	// Constantes
	public const float SPEED = 300.0f;
	private AnimatedSprite2D AnimatedSprite;
	public const float JumpVelocity = -600.0f;
	// Récupération de la gravité depuis les options
	public float gravity = ProjectSettings.GetSetting("physics/2d/default_gravity").AsSingle();
	public int coins = 0;
	
	AudioStreamPlayer2D audioPlayer;
	AudioStream coinSound;
	AudioStream jumpSound;
	
	public override void _Ready()
	{
		AnimatedSprite = GetNode<AnimatedSprite2D>("AnimatedSprite2D");
		
		audioPlayer = GetNode<AudioStreamPlayer2D>("AudioStreamPlayer2D");
		coinSound = GD.Load("res://Sounds/coin1.wav") as AudioStream;
		jumpSound = GD.Load("res://Sounds/jump1.wav") as AudioStream;
	}
	
	// Fonction qui tourne en boucle
	public override void _PhysicsProcess(double delta)
	{
		// Vélocité du personnage
		Vector2 velocity = Velocity;
		
		// Pour stocker le vecteur de direction
		Vector2 direction = Input.GetVector("ui_left", "ui_right", "ui_up", "ui_down");
		
		// Pour appliquer la gravité quand on ne touche pas le sol
		if (!IsOnFloor())
		{
			velocity.Y += gravity * (float)delta;
			AnimatedSprite.Play("jump");
		}
		
		// Gestion du saut si on appuie sur espace
		if (Input.IsActionJustPressed("ui_accept") && IsOnFloor())
		{
			velocity.Y = JumpVelocity;
			audioPlayer.Stream = jumpSound;
			audioPlayer.Play();
		}
		
		// Gestion de la touche échap & retour au menu
		if (Input.IsActionJustPressed("ui_cancel"))
		{
			GetTree().ChangeSceneToFile("res://Scenes/menu.tscn");
		}
		
		// Test de la direction
		if (direction != Vector2.Zero)
		{
			velocity.X = direction.X * SPEED;
			if (IsOnFloor())
			AnimatedSprite.Play("walk");
			if (direction.X > 0) {
				AnimatedSprite.FlipH = false;
			} else
			{
				AnimatedSprite.FlipH = true;
			}
		}
		else
		{
			velocity.X = Mathf.MoveToward(Velocity.X, 0, SPEED);
			if (IsOnFloor())
			AnimatedSprite.Play("idle");
		}
		
		
		// On applique le mouvement
		Velocity = velocity;
		MoveAndSlide();
	}
	
	public void playCoinSound()
	{
		audioPlayer.Stream = coinSound;
		audioPlayer.Play();
	}
}
